==========
References
==========

The blazar project has lots of complicated parts in it where
it helps to have an overview to understand how the internals of a particular
part work.

Internals
=========

The following is a dive into some of the internals in blazar.

* :doc:`/reference/api-microversion-history`: How blazar uses API microversion.


.. toctree::
   :hidden:
   :maxdepth: 2

   api-microversion-history
